@@ -67,7 +67,7 @@ def make_splot_data (data, *args, **kwargs):
     return subplot
 
 def multiplot(*args, **kwargs):
-    g = Gnuplot()
+    g = Gnuplot(log = True)
 
     g.set(**kwargs)
     if 'multiplot' not in kwargs.keys():
@@ -249,11 +249,14 @@ class Gnuplot(object):
             self.isMultiplot = True
 
         for k,v in kwargs.items():
+            #print("k: %s, v: %s." %(k, v))
             if (k == 'multiplot'):
-                if (v is not None):
+                if v:
                     #print("Enter Multiplot mode.")
+                    v = ""
                     self.isMultiplot = True
                 else:
+                    v = None
                     #print("Exit Multiplot mode.")
                     self.isMultiplot = False
             if isinstance(v, list):
@@ -291,6 +294,18 @@ class Gnuplot(object):
         if self.isMultiplot:
             self.unset('for [i=1:200] label i')
 
+    def splot(self, *items, **kwargs):
+        self.set(**kwargs)
+        c = 'splot'
+        for item in items:
+            c = c + " " + item + ","
+        cmd = c.rstrip(',')
+        self.cmd(cmd + '\n')
+
+        # unset the label if it's in multiplot mode.
+        if self.isMultiplot:
+            self.unset('for [i=1:200] label i')
+
     def plot_data(self, data, *items, **kwargs):
         '''
         data: The data that need to be plotted. It's either the string of list
@@ -355,18 +370,6 @@ class Gnuplot(object):
         if self.isMultiplot:
             self.unset('for [i=1:200] label i')
 
-    def splot(self, *items, **kwargs):
-        self.set(**kwargs)
-        c = 'splot'
-        for item in items:
-            c = c + " " + item + ","
-        cmd = c.rstrip(',')
-        self.cmd(cmd + '\n')
-
-        # unset the label if it's in multiplot mode.
-        if self.isMultiplot:
-            self.unset('for [i=1:200] label i')
-
 
     def evaluate(self, cmd):
         self.cmd('evaluate %s' %(cmd))
